<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request; // Pastikan ini diimport
use Illuminate\Foundation\Auth\AuthenticatesUsers;
use Illuminate\Support\Facades\Auth;

class LoginController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Login Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles authenticating users for the application and
    | redirecting them to your home screen. The controller uses a trait
    | to conveniently provide its functionality to your applications.
    |
    */

    use AuthenticatesUsers;

    /**
     * Where to redirect users after login.
     *
     * @var string
     */
    public function login(Request $request)
    {
        $credentials = $request->validate([
            'email' => 'required|email',
            'password' => 'required',
        ]);

        if (Auth::attempt($credentials, $request->remember)) {
            $user = Auth::user();
            
            // Redirect berdasarkan role
            if ($user->role === 'owner') {
                return redirect()->route('home');
            } elseif ($user->role === 'kurir') {
                return redirect()->route('kurir.dashboard');
            }
            
            // Redirect default jika role tidak dikenali
            return redirect()->route('home');
        }

        // Jika login gagal, kembalikan dengan pesan error
        return back()->withInput($request->only('email'))->with('error', 'Email atau password salah!');
    }

    /**
     * Create a new controller instance.
     */
    public function __construct()
    {
        // Hanya user yang belum login (guest) yang bisa mengakses method ini
        $this->middleware('guest')->except('logout');
    }
}
